@@ -3,7 +3,6 @@ package soju
 import (
 	"context"
 	"errors"
-	"fmt"
 	"io"
 	"net"
 	"strings"
@@ -158,7 +157,7 @@ func newConn(srv *Server, ic ircConn, options *connOptions) *conn {
 				break
 			}
 		}
-		if err := c.conn.Close(); err != nil && !errors.Is(err, net.ErrClosed) {
+		if err := c.Close(); err != nil && !errors.Is(err, net.ErrClosed) {
 			c.logger.Printf("failed to close connection: %v", err)
 		} else {
 			c.logger.Debugf("connection closed")
@@ -185,7 +184,7 @@ func (c *conn) Close() error {
 	defer c.lock.Unlock()
 
 	if c.closed {
-		return fmt.Errorf("connection already closed")
+		return net.ErrClosed
 	}
 
 	err := c.conn.Close()
@@ -195,6 +194,10 @@ func (c *conn) Close() error {
 	return err
 }
 
+// Read reads an incoming message. It must be called from a single goroutine
+// at a time.
+//
+// io.EOF is returned when there are no more messages to read.
 func (c *conn) ReadMessage() (*irc.Message, error) {
 	msg, err := c.conn.ReadMessage()
 	if errors.Is(err, net.ErrClosed) {
