@@ -21,8 +21,8 @@ import (
 	"github.com/emersion/go-sasl"
 	"gopkg.in/irc.v4"
 
-	"git.sr.ht/~emersion/soju/database"
-	"git.sr.ht/~emersion/soju/xirc"
+	"codeberg.org/emersion/soju/database"
+	"codeberg.org/emersion/soju/xirc"
 )
 
 // permanentUpstreamCaps is the static list of upstream capabilities always
@@ -191,7 +191,7 @@ type pendingUpstreamCommand struct {
 }
 
 type upstreamConn struct {
-	conn
+	*conn
 
 	network *network
 	user    *user
@@ -353,7 +353,7 @@ func connectToUpstream(ctx context.Context, network *network) (*upstreamConn, er
 
 	cm := stdCaseMapping
 	uc := &upstreamConn{
-		conn:                  *newConn(network.user.srv, newNetIRCConn(netConn), &options),
+		conn:                  newConn(network.user.srv, newNetIRCConn(netConn), &options),
 		network:               network,
 		user:                  network.user,
 		channels:              xirc.NewCaseMappingMap[*upstreamChannel](cm),
@@ -1541,7 +1541,7 @@ func (uc *upstreamConn) handleMessage(ctx context.Context, msg *irc.Message) err
 				Hostname: host,
 				Server:   server,
 				Nickname: nick,
-				Flags:    flags,
+				Flags:    stripMemberPrefixes(flags, uc),
 				Realname: realname,
 			})
 		}
@@ -1564,13 +1564,14 @@ func (uc *upstreamConn) handleMessage(ctx context.Context, msg *irc.Message) err
 			if err != nil {
 				return err
 			}
+
 			if uc.shouldCacheUserInfo(info.Nickname) {
 				uc.cacheUserInfo(info.Nickname, &upstreamUser{
 					Nickname: info.Nickname,
 					Username: info.Username,
 					Hostname: info.Hostname,
 					Server:   info.Server,
-					Flags:    info.Flags,
+					Flags:    stripMemberPrefixes(info.Flags, uc),
 					Account:  info.Account,
 					Realname: info.Realname,
 				})
